@@ -238,10 +238,23 @@ pretty.GRtime <- function(x, n = 5, ...) {
 #' @export
 
 axis.GRtime <-function(side,
-                       x = NULL,
                        at = NULL,
+                       labels = TRUE,
+                       tick = TRUE,
+                       line = NA, 
+                       pos = NA,
+                       outer = FALSE,
+                       font = NA,
+                       lty = "solid",
+                       lwd = 1,
+                       lwd.ticks = lwd,
+                       col = NULL,
+                       col.ticks = NULL,
+                       hadj = NA,
+                       padj = NA,
+                       gap.axis = NA,
+                       x = NULL,
                        format = NULL,
-                       labels  = TRUE,
                        add = TRUE,  ...){
   if (is.null(at)){
     att <- NULL
@@ -262,6 +275,6 @@ axis.GRtime <-function(side,
   if(missing(labels) || (is.logical(labels) && labels)){
     labels <- format(at, format = format)}
   if(add){
-    axis(side, at = at, labels = labels, ...)}
+    axis(side, at = at, labels = labels, tick = tick, line = line, pos = pos, outer = outer, font = font, lty = lty, lwd = lwd, lwd.ticks = lwd.ticks, col = col, col.ticks = col.ticks, hadj = hadj, padj = padj, gap.axis = gap.axis, ...)}
   invisible(list(side = side, at = at, labels = labels))
 }
