@@ -154,7 +154,7 @@ conv01 <- function(x){
 #'
 #' @description quantile version of bt
 #'
-#' @param x First object to pass
+#' @param X First object to pass
 #' @param y Second object to pass
 #' @importFrom stats quantile
 #'
@@ -192,7 +192,7 @@ conv01 <- function(x){
 #' takes \code{[min, max)}, or \code{c("[", min, max, "]")} style second terms
 #' default is \code{[min, max]} for c(,) terms
 #'
-#' @param x First object to pass
+#' @param X First object to pass
 #' @param y Second object to pass
 #'
 #' @keywords internal
@@ -241,8 +241,8 @@ removeZero <- function(obj){
 #' @param shifting Shifting the sequence by this value
 #'
 #' @keywords internal
-
-seq.log <- function(from = 1,
+#' @method seq log
+seq.log <- function(...,from = 1,
                     to = 1,
                     length.out = 50,
                     add.zero = FALSE,
@@ -263,9 +263,9 @@ seq.log <- function(from = 1,
 
 #' @title expand
 #'
-#' @description expand an obecjt x
+#' @description expand an object X
 #'
-#' @param x object to expand
+#' @param X object to expand
 #' @param length length to expand object
 #'
 #' @importFrom utils tail
